@@ -1,16 +1,16 @@
-# @(#)$Id: Constraints.pm 380 2012-05-19 21:01:16Z pjf $
+# @(#)$Id: Constraints.pm 401 2012-07-10 00:31:02Z pjf $
 
 package File::DataClass::Constraints;
 
 use strict;
 use warnings;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.10.%d', q$Rev: 380 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.11.%d', q$Rev: 401 $ =~ /\d+/gmx );
 
 use MooseX::Types -declare => [ qw(Cache DummyClass HashRefOfBools Lock Path
                                    Directory File Result Symbol) ];
 use MooseX::Types::Moose        qw(ArrayRef CodeRef HashRef Object Str Undef);
-use File::DataClass::IO;
+use File::DataClass::IO ();
 use Scalar::Util qw(blessed);
 
 subtype Cache, as Object,
@@ -47,30 +47,30 @@ subtype Path, as Object,
    };
 
 coerce Path,
-   from ArrayRef, via { io( $_ ) },
-   from CodeRef,  via { io( $_ ) },
-   from Str,      via { io( $_ ) },
-   from Undef,    via { io( $_ ) };
+   from ArrayRef, via { File::DataClass::IO->new( $_ ) },
+   from CodeRef,  via { File::DataClass::IO->new( $_ ) },
+   from Str,      via { File::DataClass::IO->new( $_ ) },
+   from Undef,    via { File::DataClass::IO->new( $_ ) };
 
 subtype Directory, as Path,
    where   { $_->is_dir  },
    message { 'Path '.($_ ? $_.' is not a directory' : 'not specified') };
 
 coerce Directory,
-   from ArrayRef, via { io( $_ ) },
-   from CodeRef,  via { io( $_ ) },
-   from Str,      via { io( $_ ) },
-   from Undef,    via { io( $_ ) };
+   from ArrayRef, via { File::DataClass::IO->new( $_ ) },
+   from CodeRef,  via { File::DataClass::IO->new( $_ ) },
+   from Str,      via { File::DataClass::IO->new( $_ ) },
+   from Undef,    via { File::DataClass::IO->new( $_ ) };
 
 subtype File, as Path,
    where   { $_->is_file },
    message { 'Path '.($_ ? $_.' is not a file' : 'not specified') };
 
 coerce File,
-   from ArrayRef, via { io( $_ ) },
-   from CodeRef,  via { io( $_ ) },
-   from Str,      via { io( $_ ) },
-   from Undef,    via { io( $_ ) };
+   from ArrayRef, via { File::DataClass::IO->new( $_ ) },
+   from CodeRef,  via { File::DataClass::IO->new( $_ ) },
+   from Str,      via { File::DataClass::IO->new( $_ ) },
+   from Undef,    via { File::DataClass::IO->new( $_ ) };
 
 no MooseX::Types;
 
@@ -86,7 +86,7 @@ File::DataClass::Constraints - Role defining package constraints
 
 =head1 Version
 
-0.10.$Revision: 380 $
+0.11.$Revision: 401 $
 
 =head1 Synopsis
 
