@@ -1,10 +1,10 @@
-# @(#)$Id: ResultSource.pm 380 2012-05-19 21:01:16Z pjf $
+# @(#)$Id: ResultSource.pm 401 2012-07-10 00:31:02Z pjf $
 
 package File::DataClass::ResultSource;
 
 use strict;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.10.%d', q$Rev: 380 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.11.%d', q$Rev: 401 $ =~ /\d+/gmx );
 
 use Moose;
 use File::DataClass::Constants;
@@ -13,20 +13,40 @@ use File::DataClass::ResultSet;
 
 has 'attributes'           => is => 'ro', isa => 'ArrayRef[Str]',
    default                 => sub { [] };
+
 has 'defaults'             => is => 'ro', isa => 'HashRef',
    default                 => sub { {} };
+
 has 'name'                 => is => 'ro', isa => 'Str',
    default                 => NUL;
+
 has 'label_attr'           => is => 'ro', isa => 'Str',
    default                 => NUL;
+
 has 'resultset_attributes' => is => 'ro', isa => 'HashRef',
    default                 => sub { {} };
+
 has 'resultset_class'      => is => 'ro', isa => 'ClassName',
    default                 => q(File::DataClass::ResultSet);
+
 has 'schema'               => is => 'ro', isa => 'Object',
    required                => TRUE, weak_ref => TRUE,
    handles                 => [ qw(path storage) ];
 
+
+has '_attributes' => is => 'ro', isa => 'HashRef',
+   builder        => '_build_attributes', init_arg => undef, lazy => TRUE;
+
+sub columns {
+   return @{ $_[ 0 ]->attributes };
+}
+
+sub has_column {
+   my $attr = $_[ 0 ]->_attributes; my $key = $_[ 1 ] || q(_invalid_key_);
+
+   return exists $attr->{ $key } and $attr->{ $key } ? TRUE : FALSE;
+}
+
 sub resultset {
    my $self = shift;
 
@@ -35,6 +55,16 @@ sub resultset {
    return $self->resultset_class->new( $attrs );
 }
 
+# Private methods
+
+sub _build_attributes {
+   my $self = shift; my $attr = {};
+
+   $attr->{ $_ } = TRUE for (@{ $self->attributes });
+
+   return $attr;
+}
+
 __PACKAGE__->meta->make_immutable;
 
 no Moose;
@@ -51,7 +81,7 @@ File::DataClass::ResultSource - A source of result sets for a given schema
 
 =head1 Version
 
-0.10.$Revision: 380 $
+0.11.$Revision: 401 $
 
 =head1 Synopsis
 
@@ -79,10 +109,14 @@ inherit from this
 
 =head1 Configuration and Environment
 
+Defines the following attributes
+
 =over 3
 
 =item B<attributes>
 
+Array ref of attributes defined in this result source
+
 =item B<defaults>
 
 =item B<name>
@@ -101,8 +135,22 @@ inherit from this
 
 =head1 Subroutines/Methods
 
+=head2 columns
+
+   @attributes = $self->columns;
+
+Returns a list of attributes
+
+=head2 has_column
+
+   $bool = $self->has_column( $attribute_name );
+
+Predicate return true if the attribute exists, false otherwise
+
 =head2 resultset
 
+   $rs = $self->resultset;
+
 Creates and returns a new L<File::DataClass::ResultSet> object
 
 =head1 Diagnostics
