@@ -1,10 +1,10 @@
-# @(#)$Id: WithLanguage.pm 380 2012-05-19 21:01:16Z pjf $
+# @(#)$Id: WithLanguage.pm 401 2012-07-10 00:31:02Z pjf $
 
 package File::DataClass::Schema::WithLanguage;
 
 use strict;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.10.%d', q$Rev: 380 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.11.%d', q$Rev: 401 $ =~ /\d+/gmx );
 
 use Moose;
 use File::DataClass::Constants;
@@ -12,12 +12,18 @@ use File::DataClass::Constraints qw(Directory);
 use File::DataClass::ResultSource::WithLanguage;
 use File::DataClass::Storage::WithLanguage;
 use File::Gettext::Constants;
-use MooseX::Types::Moose qw(Str);
+use MooseX::Types  -declare => [ qw(LanguageType) ];
+use MooseX::Types::Moose         qw(Str Undef);
 
 extends qw(File::DataClass::Schema);
 
-has 'lang'      => is => 'rw', isa => Str,     default => LANG;
-has 'localedir' => is => 'ro', isa => Directory, coerce  => TRUE,
+subtype LanguageType, as Str;
+coerce  LanguageType, from Undef, via { LANG };
+
+has 'lang'      => is => 'rw', isa => LanguageType, coerce => TRUE,
+   default      => LANG;
+
+has 'localedir' => is => 'ro', isa => Directory, coerce => TRUE,
    default      => sub { DIRECTORIES->[ 0 ] };
 
 around BUILDARGS => sub {
@@ -56,7 +62,7 @@ File::DataClass::Schema::WithLanguage - Adds language support to the default sch
 
 =head1 Version
 
-0.10.$Revision: 380 $
+0.11.$Revision: 401 $
 
 =head1 Synopsis
 
