@@ -1,27 +1,58 @@
-# @(#)$Id: Storage.pm 380 2012-05-19 21:01:16Z pjf $
+# @(#)$Id: Storage.pm 401 2012-07-10 00:31:02Z pjf $
 
 package File::DataClass::Storage;
 
 use strict;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.10.%d', q$Rev: 380 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.11.%d', q$Rev: 401 $ =~ /\d+/gmx );
 
 use Moose;
 use Class::Null;
 use English     qw(-no_match_vars);
 use File::Copy;
 use File::DataClass::Constants;
+use File::DataClass::Functions qw(is_stale merge_hash_data throw);
 use File::DataClass::HashMerge;
-use Hash::Merge qw(merge);
 use Try::Tiny;
 
-with qw(File::DataClass::Util);
+has 'backup'   => is => 'ro', isa => 'Str', default => NUL;
 
-has 'backup' => is => 'ro', isa => 'Str',    default  => NUL;
-has 'extn'   => is => 'ro', isa => 'Str',    default  => NUL;
-has 'schema' => is => 'ro', isa => 'Object', required => TRUE, weak_ref => TRUE,
-   handles   => { _cache => q(cache), _debug => q(debug), _lock => q(lock),
-                  _log   => q(log),   _perms => q(perms) };
+has 'encoding' => is => 'ro', isa => 'Str', default => NUL;
+
+has 'extn'     => is => 'ro', isa => 'Str', default => NUL;
+
+has 'schema'   => is => 'ro', isa => 'Object',
+   handles     => { _cache => q(cache), _debug => q(debug), _lock => q(lock),
+                    _log   => q(log),   _perms => q(perms) }, required => TRUE,
+   weak_ref    => TRUE;
+
+sub create_or_update {
+   my ($self, $path, $result, $updating, $cond) = @_;
+
+   my $element = $result->_resultset->source->name;
+
+   $self->validate_params( $path, $element ); my $updated;
+
+   my $data = ($self->_read_file( $path, TRUE ))[ 0 ] || {};
+
+   try {
+      my $filter = sub { __get_src_attributes( $cond, $_[ 0 ] ) };
+      my $name   = $result->name; $data->{ $element } ||= {};
+
+      not $updating and exists $data->{ $element }->{ $name }
+         and throw error => 'File [_1] element [_2] already exists',
+                   args  => [ $path, $name ], level => 4;
+
+      $updated = File::DataClass::HashMerge->merge
+         ( \$data->{ $element }->{ $name }, $result, $filter );
+   }
+   catch { $self->_lock->reset( k => $path ); throw $_ };
+
+   if ($updated) { $self->_write_file( $path, $data, not $updating ) }
+   else { $self->_lock->reset( k => $path ) }
+
+   return $updated;
+}
 
 sub delete {
    my ($self, $path, $result) = @_;
@@ -52,15 +83,10 @@ sub dump {
       $self->_write_file( $path, $data, TRUE ) } );
 }
 
-sub extensions {
-   return { '.json' => [ q(JSON) ],
-            '.xml'  => [ q(XML::Simple), q(XML::Bare) ], };
-}
-
 sub insert {
    my ($self, $path, $result) = @_;
 
-   return $self->_create_or_update( $path, $result, FALSE, sub { TRUE } );
+   return $self->create_or_update( $path, $result, FALSE, sub { TRUE } );
 }
 
 sub load {
@@ -70,17 +96,38 @@ sub load {
       and return ($self->_read_file( $paths[ 0 ], FALSE ))[ 0 ] || {};
 
    my ($data, $meta, $newest) = $self->_cache->get_by_paths( \@paths );
-   my $cache_mtime  = $self->_meta_unpack( $meta );
+   my $cache_mtime  = $self->meta_unpack( $meta );
 
-   not $self->is_stale( $data, $cache_mtime, $newest ) and return $data;
+   not is_stale $data, $cache_mtime, $newest and return $data;
 
-   ($data, $newest) = $self->_load( \@paths );
+   $data = {}; $newest = 0;
 
-   $self->_cache->set_by_paths( \@paths, $data, $self->_meta_pack( $newest ) );
+   for my $path (@paths) {
+      my ($red, $path_mtime) = $self->_read_file( $path, FALSE ); $red or next;
+
+      $path_mtime > $newest and $newest = $path_mtime;
+      merge_hash_data $data, $red;
+   }
+
+   $self->_cache->set_by_paths( \@paths, $data, $self->meta_pack( $newest ) );
 
    return $data;
 }
 
+sub meta_pack {
+   # Can be modified in a subclass
+   my ($self, $mtime) = @_; return { mtime => $mtime };
+}
+
+sub meta_unpack {
+   # Can be modified in a subclass
+   my ($self, $attrs) = @_; return $attrs ? $attrs->{mtime} : undef;
+}
+
+sub read_file {
+   return shift->_read_file( @_ );
+}
+
 sub select {
    my ($self, $path, $element) = @_;
 
@@ -104,10 +151,7 @@ sub txn_do {
       if ($wantarray) { @{ $res } = $code_ref->() }
       else { $res = $code_ref->() }
    }
-   catch {
-      $self->_lock->reset( k => $key );
-      $self->throw( error => $_, level => 7 );
-   };
+   catch { $self->_lock->reset( k => $key ); throw error => $_, level => 7 };
 
    $self->_lock->reset( k => $key );
 
@@ -115,94 +159,33 @@ sub txn_do {
 }
 
 sub update {
-   my ($self, $path, $result, $updating, $condition) = @_;
+   my ($self, $path, $result, $updating, $cond) = @_;
 
-   defined $updating or $updating = TRUE; $condition ||= sub { TRUE };
+   defined $updating or $updating = TRUE; $cond ||= sub { TRUE };
 
-   return $self->_create_or_update( $path, $result,
-                                    $updating, $condition )
-       or $self->throw( 'Nothing updated' );
+   my $updated = $self->create_or_update( $path, $result, $updating, $cond )
+      or throw class => 'NothingUpdated', error => 'Nothing updated',
+               level => 5;
+
+   return $updated;
 }
 
 sub validate_params {
    my ($self, $path, $element) = @_;
 
-   $path or $self->throw( error => 'No file path specified', level => 4 );
+   $path or throw error => 'No file path specified', level => 4;
 
-   blessed $path or $self->throw( error => 'Path [_1] is not blessed',
-                                  args  => [ $path ], level => 4 );
+   blessed $path or throw error => 'Path [_1] is not blessed',
+                          args  => [ $path ], level => 4;
 
-   $element or $self->throw( error => 'Path [_1] no element specified',
-                             args  => [ $path ], level => 4 );
+   $element or throw error => 'Path [_1] no element specified',
+                     args  => [ $path ], level => 4;
 
    return;
 }
 
 # Private methods
 
-sub _create_or_update {
-   my ($self, $path, $result, $updating, $condition) = @_;
-
-   my $element = $result->_resultset->source->name;
-
-   $self->validate_params( $path, $element ); my $updated;
-
-   my $data = ($self->_read_file( $path, TRUE ))[ 0 ] || {};
-
-   try {
-      my $filter = sub { __get_src_attributes( $condition, $_[ 0 ] ) };
-      my $name   = $result->name; $data->{ $element } ||= {};
-
-      not $updating and exists $data->{ $element }->{ $name }
-         and $self->throw( error => 'File [_1] element [_2] already exists',
-                           args  => [ $path, $name ], level => 4 );
-
-      $updated = File::DataClass::HashMerge->merge
-         ( \$data->{ $element }->{ $name }, $result, $filter );
-   }
-   catch { $self->_lock->reset( k => $path ); $self->throw( $_ ) };
-
-   if ($updated) { $self->_write_file( $path, $data, not $updating ) }
-   else { $self->_lock->reset( k => $path ) }
-
-   return $updated;
-}
-
-sub _load {
-   my ($self, $paths) = @_; my $data = {}; my $newest = 0;
-
-   for my $path (@{ $paths }) {
-      my ($red, $path_mtime) = $self->_read_file( $path, FALSE ); $red or next;
-
-      $path_mtime > $newest and $newest = $path_mtime;
-      $self->_merge_hash_data( $data, $red );
-   }
-
-   return ($data, $newest);
-}
-
-sub _merge_hash_data {
-   my ($self, $existing, $new) = @_;
-
-   for (keys %{ $new }) {
-      $existing->{ $_ } = exists $existing->{ $_ }
-                        ? merge( $existing->{ $_ }, $new->{ $_ } )
-                        : $new->{ $_ };
-   }
-
-   return;
-}
-
-sub _meta_pack {
-   # Can be modified in a subclass
-   my ($self, $mtime) = @_; return { mtime => $mtime };
-}
-
-sub _meta_unpack {
-   # Can be modified in a subclass
-   my ($self, $attrs) = @_; return $attrs ? $attrs->{mtime} : undef;
-}
-
 sub _read_file {
    my ($self, $path, $for_update) = @_;
 
@@ -212,20 +195,20 @@ sub _read_file {
       ($data, $meta)  = $self->_cache->get( $path );
       $path_mtime     = $path->stat->{mtime};
 
-      my $cache_mtime = $self->_meta_unpack( $meta );
+      my $cache_mtime = $self->meta_unpack( $meta );
 
-      if ($self->is_stale( $data, $cache_mtime, $path_mtime )) {
+      if (is_stale $data, $cache_mtime, $path_mtime) {
          if ($for_update and not $path->is_file) { $data = undef }
          else {
             $data = inner( $path->lock ); $path->close;
-            $meta = $self->_meta_pack( $path_mtime );
+            $meta = $self->meta_pack( $path_mtime );
             $self->_cache->set( $path, $data, $meta );
             $self->_debug and $self->_log->debug( "Read file  ${path}" );
          }
       }
       else { $self->_debug and $self->_log->debug( "Read cache ${path}" ) }
    }
-   catch { $self->_lock->reset( k => $path ); $self->throw( $_ ) };
+   catch { $self->_lock->reset( k => $path ); throw $_ };
 
    $for_update or $self->_lock->reset( k => $path );
 
@@ -237,21 +220,21 @@ sub _write_file {
 
    try {
       $create or $path->is_file
-         or $self->throw( error => 'File [_1] not found', args => [ $path ] );
+         or throw error => 'File [_1] not found', args => [ $path ];
 
       $path->is_file or $path->perms( $self->_perms );
 
       if ($self->backup and $path->is_file and not $path->empty) {
-         copy( $path.NUL, $path.$self->backup ) or $self->throw( $ERRNO );
+         copy( $path.NUL, $path.$self->backup ) or throw $ERRNO;
       }
 
       try   { $data = inner( $path->atomic->lock, $data ); $path->close }
-      catch { $path->delete; $self->throw( $_ ) };
+      catch { $path->delete; throw $_ };
 
       $self->_cache->remove( $path );
       $self->_debug and $self->_log->debug( "Write file ${path}" )
    }
-   catch { $self->_lock->reset( k => $path ); $self->throw( $_ ) };
+   catch { $self->_lock->reset( k => $path ); throw $_ };
 
    $self->_lock->reset( k => $path );
    return $data;
@@ -260,11 +243,11 @@ sub _write_file {
 # Private subroutines
 
 sub __get_src_attributes {
-   my ($condition, $src) = @_;
+   my ($cond, $src) = @_;
 
    return grep { not m{ \A _ }mx
                  and $_ ne q(name)
-                 and $condition->( $_ ) } keys %{ $src };
+                 and $cond->( $_ ) } keys %{ $src };
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -283,7 +266,7 @@ File::DataClass::Storage - Storage base class
 
 =head1 Version
 
-0.10.$Revision: 380 $
+0.11.$Revision: 401 $
 
 =head1 Synopsis
 
@@ -293,6 +276,12 @@ Storage base class
 
 =head1 Subroutines/Methods
 
+=head2 create_or_update
+
+   $bool = $self->create_or_update( $path, $result, $updating, $condition );
+
+Does the heavy lifting for L</insert> and L</update>
+
 =head2 delete
 
    $bool = $storage->delete( $path, $result );
@@ -307,14 +296,6 @@ an error otherwise. Path is an instance of L<File::DataClass::IO>
 Dumps the data to the specified path. Path is an instance of
 L<File::DataClass::IO>
 
-=head2 extensions
-
-   $hash_ref = $storage->extensions;
-
-Returns a hash ref whose keys are the supported extensions and whose values
-are an array ref of storage subclasses that implement reading/writing files
-with that extension
-
 =head2 insert
 
    $bool = $storage->insert( $path, $result );
@@ -329,6 +310,16 @@ an error otherwise. Path is an instance of L<File::DataClass::IO>
 Loads each of the specified files merging the resultant hash ref which
 it returns. Paths are instances of L<File::DataClass::IO>
 
+=head2 meta_pack
+
+=head2 meta_unpack
+
+=head2 read_file
+
+   ($data, $mtime) = $self->read_file( $path, $for_update ):
+
+Read a file from cache or disk
+
 =head2 select
 
    $hash_ref = $storage->select( $path );
@@ -349,12 +340,6 @@ an error otherwise. Path is an instance of L<File::DataClass::IO>
 
 =head2 validate_params
 
-=head2 _merge_hash_data
-
-   $self->_merge_hash_data( $existsing, $new );
-
-Uses L<Hash::Merge> to merge data from the new hash ref in with the existsing
-
 =head1 Diagnostics
 
 None
@@ -369,12 +354,6 @@ None
 
 =item L<File::DataClass::HashMerge>
 
-=item L<File::DataClass::Util>
-
-=item L<Hash::Merge>
-
-=item L<Scalar::Util>
-
 =back
 
 =head1 Incompatibilities
