@@ -1,99 +1,114 @@
-# @(#)$Id: Any.pm 381 2012-05-19 21:01:33Z pjf $
+# @(#)$Id: Any.pm 401 2012-07-10 00:31:02Z pjf $
 
 package File::DataClass::Storage::Any;
 
 use strict;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.10.%d', q$Rev: 381 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.11.%d', q$Rev: 401 $ =~ /\d+/gmx );
 
 use Moose;
+use File::Basename             qw(basename);
 use File::DataClass::Constants;
+use File::DataClass::Functions qw(ensure_class_loaded is_stale merge_hash_data
+                                  throw);
 use File::DataClass::Storage;
 
-with qw(File::DataClass::Util);
-
 has 'schema' => is => 'ro', isa => 'Object', required => TRUE, weak_ref => TRUE,
    handles   => [ qw(cache storage_attributes storage_base), ];
 
 has 'stores' => is => 'ro', isa => 'HashRef', lazy => TRUE,
    builder   => '_build_stores';
 
-sub delete {
-   my ($self, $path, $result) = @_;
+sub create_or_update {
+   return shift->_get_store_from_extension( $_[ 0 ] )->create_or_update( @_ );
+}
 
-   return $self->_get_store_from_extension( $path )->delete( $path, $result );
+sub delete {
+   return shift->_get_store_from_extension( $_[ 0 ] )->delete( @_ );
 }
 
 sub dump {
-   my ($self, $path, $data) = @_;
-
-   return $self->_get_store_from_extension( $path )->dump( $path, $data );
+   return shift->_get_store_from_extension( $_[ 0 ] )->dump( @_ );
 }
 
-sub extensions {
-   return File::DataClass::Storage->extensions;
+sub extn {
+   return sub {
+      my $path = shift || NUL; my ($extn) = $path =~ m{ \. ([^\.]+) \z }mx;
+
+      return $extn ? q(.).$extn : NUL;
+   };
 }
 
 sub insert {
-   my ($self, $path, $result) = @_;
-
-   return $self->_get_store_from_extension( $path )->insert( $path, $result );
+   return shift->_get_store_from_extension( $_[ 0 ] )->insert( @_ );
 }
 
 sub load {
    my ($self, @paths) = @_; $paths[ 0 ] or return {};
 
    my ($data, $meta, $newest) = $self->cache->get_by_paths( \@paths );
-   my $cache_mtime  = $self->_meta_unpack( $meta );
+   my $cache_mtime  = $self->meta_unpack( $meta );
 
-   not $self->is_stale( $data, $cache_mtime, $newest ) and return $data;
+   not is_stale $data, $cache_mtime, $newest and return $data;
 
-   ($data, $newest) = $self->_load( \@paths );
-   $self->_meta_pack( $meta, $newest );
-   $self->cache->set_by_paths( \@paths, $data, $meta );
+   $data = {}; $newest = 0;
+
+   for my $path (@paths) {
+      my $store = $self->_get_store_from_extension( $path );
+      my ($red, $path_mtime) = $store->read_file( $path, FALSE ); $red or next;
+
+      $path_mtime > $newest and $newest = $path_mtime;
+      merge_hash_data $data, $red;
+   }
+
+   $self->cache->set_by_paths( \@paths, $data, $self->meta_pack( $newest ) );
    return $data;
 }
 
-sub select {
-   my ($self, $path, $element) = @_;
+sub meta_pack {
+   my ($self, $mtime) = @_; my $attr = $self->{_meta_cache} || {};
 
-   return $self->_get_store_from_extension( $path )->select( $path, $element );
+   $attr->{mtime} = $mtime; return $attr;
+}
+
+sub meta_unpack {
+   my ($self, $attr) = @_; $self->{_meta_cache} = $attr;
+
+   return $attr ? $attr->{mtime} : undef;
+};
+
+sub read_file {
+   return shift->_get_store_from_extension( $_[ 0 ] )->read_file( @_ );
+}
+
+sub select {
+   return shift->_get_store_from_extension( $_[ 0 ] )->select( @_ );
 }
 
 sub txn_do {
-   my ($self, $path, $code_ref) = @_;
-
-   return $self->_get_store_from_extension( $path )->txn_do( $path, $code_ref );
+   return shift->_get_store_from_extension( $_[ 0 ] )->txn_do( @_ );
 }
 
 sub update {
-   my ($self, $path, $result, $updating, $condition) = @_;
-
-   my $store = $self->_get_store_from_extension( $path );
-
-   return $store->update( $path, $result, $updating, $condition );
+   return shift->_get_store_from_extension( $_[ 0 ] )->update( @_ );
 }
 
 sub validate_params {
-   my ($self, $path, $element) = @_;
-
-   my $store = $self->_get_store_from_extension( $path );
-
-   return $store->validate_params( $path, $element );
+   return shift->_get_store_from_extension( $_[ 0 ] )->validate_params( @_ );
 }
 
 # Private methods
 
 sub _build_stores {
-   my $self = shift; my $stores = {}; my $extensions = $self->extensions;
+   my $self = shift; my $stores = {};
 
-   for my $extn (keys %{ $extensions }) {
-      my $class = $extensions->{ $extn }->[ 0 ];
+   for my $extn (keys %{ EXTENSIONS() }) {
+      my $class = EXTENSIONS()->{ $extn }->[ 0 ];
 
       if (q(+) eq substr $class, 0, 1) { $class = substr $class, 1 }
       else { $class = $self->storage_base.q(::).$class }
 
-      $self->ensure_class_loaded( $class );
+      ensure_class_loaded $class;
 
       $stores->{ $extn } = $class->new( { %{ $self->storage_attributes },
                                           schema => $self->schema } );
@@ -103,41 +118,17 @@ sub _build_stores {
 }
 
 sub _get_store_from_extension {
-   my ($self, $path) = @_; my $file = $self->basename( $path );
+   my ($self, $path) = @_; my $file = basename( NUL.$path );
 
    my $extn = (split m{ \. }mx, $file)[ -1 ]
-      or $self->throw( error => 'File [_1] has no extension',
-                       args  => [ $file ] );
+      or throw error => 'File [_1] has no extension', args => [ $file ];
 
    my $store = $self->stores->{ q(.).$extn }
-      or $self->throw( error => 'Extension [_1] has no store',
-                       args  => [ $extn ] );
+      or throw error => 'Extension [_1] has no store', args => [ $extn ];
 
    return $store;
 }
 
-sub _load {
-   my ($self, $paths) = @_; my $data = {}; my $newest = 0;
-
-   for my $path (@{ $paths }) {
-      my $store = $self->_get_store_from_extension( $path );
-      my ($red, $path_mtime) = $store->_read_file( $path, FALSE ); $red or next;
-
-      $path_mtime > $newest and $newest = $path_mtime;
-      $store->_merge_hash_data( $data, $red );
-   }
-
-   return ($data, $newest);
-}
-
-sub _meta_pack {
-   my ($self, $attrs, $mtime) = @_; $attrs->{mtime} = $mtime;
-}
-
-sub _meta_unpack {
-   my ($self, $attrs) = @_; return $attrs ? $attrs->{mtime} : undef;
-}
-
 __PACKAGE__->meta->make_immutable;
 
 no Moose;
@@ -154,7 +145,7 @@ File::DataClass::Storage::Any - Selects storage class using the extension on the
 
 =head1 Version
 
-0.1.$Revision: 381 $
+0.1.$Revision: 401 $
 
 =head1 Synopsis
 
@@ -170,18 +161,24 @@ Selects storage class using the extension on the path
 
 =head1 Subroutines/Methods
 
+=head2 create_or_update
+
 =head2 delete
 
 =head2 dump
 
-=head2 extensions
-
-Class method that proxies the call to L<File::DataClass::Storage/extensions>
+=head2 extn
 
 =head2 insert
 
 =head2 load
 
+=head2 meta_pack
+
+=head2 meta_unpack
+
+=head2 read_file
+
 =head2 select
 
 =head2 txn_do
