@@ -1,10 +1,10 @@
-# @(#)$Id: Bare.pm 380 2012-05-19 21:01:16Z pjf $
+# @(#)$Id: Bare.pm 401 2012-07-10 00:31:02Z pjf $
 
 package File::DataClass::Storage::XML::Bare;
 
 use strict;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.10.%d', q$Rev: 380 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.11.%d', q$Rev: 401 $ =~ /\d+/gmx );
 
 use File::DataClass::Constants;
 use XML::Bare;
@@ -18,6 +18,8 @@ my $PADDING = q(  );
 augment '_read_file' => sub {
    my ($self, $rdr) = @_; my $data;
 
+   $self->encoding and $rdr->encoding( $self->encoding );
+
    $data = $self->_dtd_parse( $rdr->all );
    $data = XML::Bare->new( text => $data )->parse() || {};
    $data = $data->{ $self->root_name } || {};
@@ -28,6 +30,7 @@ augment '_read_file' => sub {
 augment '_write_file' => sub {
    my ($self, $wtr, $data) = @_;
 
+   $self->encoding and $wtr->encoding( $self->encoding );
    $self->_dtd->[0] and $wtr->println( @{ $self->_dtd } );
    $wtr->append( $self->_write_filter( 0, $self->root_name, $data ) );
    return $data;
@@ -163,7 +166,7 @@ File::DataClass::Storage::XML::Bare - Read/write XML data storage model
 
 =head1 Version
 
-0.10.$Revision: 380 $
+0.11.$Revision: 401 $
 
 =head1 Synopsis
 
